@@ -173,6 +173,33 @@ def RadioButton(group, label, callback=None):
     rdb.show()
     return rdb
 
+def nComboBox(exname, name, default, popdown_strings):
+    c = gtk.combo_box_new_text()
+    for n in popdown_strings:
+        c.append_text(n)
+    c.m_exname = exname
+    c.m_name = name
+    val = cfg.get_string("%s/%s=X" % (c.m_exname, c.m_name))
+    if val == 'X':
+        cfg.set_int("%s/%s" % (exname, name),
+            popdown_strings.index(default))
+        c.set_active(popdown_strings.index(default))
+    else:
+        try:
+            i = cfg.get_int("%s/%s" % (c.m_exname, c.m_name))
+        except ValueError:
+            i = 0
+            cfg.set_int("%s/%s" % (c.m_exname, c.m_name), 0)
+        if i >= len(popdown_strings):
+            i = 0
+            cfg.set_int("%s/%s" % (c.m_exname, c.m_name), 0)
+        c.set_active(cfg.get_int("%s/%s" % (c.m_exname, c.m_name)))
+    def f(combobox):
+        cfg.set_int("%s/%s" % (exname, name), combobox.get_active())
+    c.connect('changed', f)
+    return c
+
+
 class nCombo(gtk.Combo, cfg.ConfigUtils):
     def __init__(self, exname, name, default, popdown_strings):
         """
