@@ -8,8 +8,8 @@ most of the files in solfege because they require i18n setup.
 import sys
 import pydoc
 sys.path.insert(0, ".")
-import src.i18n
-src.i18n.setup(".")
+import solfege.i18n
+solfege.i18n.setup(".")
 
 pydoc.cli()
 
